engine

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 11, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package engine provides the template rendering engine.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Engine

type Engine struct {
	// contains filtered or unexported fields
}

Engine handles template parsing and execution.

func New

func New() *Engine

New creates a new template engine with custom functions.

func (*Engine) RenderFile

func (e *Engine) RenderFile(path string, data any) (string, error)

RenderFile renders a template file with the given data.

func (*Engine) RenderString

func (e *Engine) RenderString(tmpl string, data any) (string, error)

RenderString renders a template string with the given data.

Jump to