Documentation
¶
Overview ¶
Package data provides JSON and YAML data loading functionality.
Package data provides JSON and YAML data loading functionality.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Load ¶
Load reads data from a file and returns it as a generic interface. It automatically detects the format based on file extension.
func LoadReader ¶
LoadReader reads data from a reader in the specified format.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.